@@ -67,23 +67,12 @@ utils::globalVariables(c("offset"))
 #'           \code{df.pos} for the positive values and \code{df.neutral} for the neutral category values).
 #' 
 #' @examples
-#' # prepare data for dichotomous likert scale, 5 items
-#' likert_2 <- data.frame(
-#'   as.factor(sample(1:2, 500, replace = TRUE, prob = c(0.3,0.7))),
-#'   as.factor(sample(1:2, 500, replace = TRUE, prob = c(0.6,0.4))),
-#'   as.factor(sample(1:2, 500, replace = TRUE, prob = c(0.25,0.75))),
-#'   as.factor(sample(1:2, 500, replace = TRUE, prob = c(0.9,0.1))),
-#'   as.factor(sample(1:2, 500, replace = TRUE, prob = c(0.35,0.65))))
-#'   
-#' # create labels
-#' levels_2 <- c("Agree", "Disagree")
-#'                        
 #' # prepare data for 4-category likert scale, with neutral category 5 items
-#' Q1 <- as.factor(sample(1:4, 500, replace = TRUE, prob = c(0.2, 0.3, 0.1, 0.4)))
-#' Q2 <- as.factor(sample(1:4, 500, replace = TRUE, prob = c(0.5, 0.25, 0.15, 0.1)))
-#' Q3 <- as.factor(sample(1:4, 500, replace = TRUE, prob = c(0.25, 0.1, 0.4, 0.25)))
-#' Q4 <- as.factor(sample(1:4, 500, replace = TRUE, prob = c(0.1, 0.4, 0.4, 0.1)))
-#' Q5 <- as.factor(sample(1:4, 500, replace = TRUE, prob = c(0.35, 0.25, 0.15, 0.25)))
+#' Q1 <- as.factor(sample(1:4, 500, replace = TRUE, prob = c(.2, .3, .1, .4)))
+#' Q2 <- as.factor(sample(1:5, 500, replace = TRUE, prob = c(.5, .25, .12, .09, .03)))
+#' Q3 <- as.factor(sample(1:4, 500, replace = TRUE, prob = c(.25, .1, .4, .25)))
+#' Q4 <- as.factor(sample(1:5, 500, replace = TRUE, prob = c(.1, .3, .38, .1, .12)))
+#' Q5 <- as.factor(sample(1:4, 500, replace = TRUE, prob = c(.35, .25, .15, .25)))
 #' 
 #' likert_4 <- data.frame(Q1, Q2, Q3, Q4, Q5)
 #' 
@@ -91,38 +80,21 @@ utils::globalVariables(c("offset"))
 #' levels_4 <- c("Strongly agree", "Agree", "Disagree", 
 #'               "Strongly Disagree", "Don't know")
 #' 
-#' # prepare data for 6-category likert scale, 5 items
-#' likert_6 <- data.frame()
-#' 
-#' Q1 <- as.factor(sample(1:6, 500, replace = TRUE, prob = c(0.2,0.1,0.1,0.3,0.2,0.1)))
-#' Q2 <- as.factor(sample(1:6, 500, replace = TRUE, prob = c(0.15,0.15,0.3,0.1,0.1,0.2)))
-#' Q3 <- as.factor(sample(1:6, 500, replace = TRUE, prob = c(0.2,0.25,0.05,0.2,0.2,0.2)))
-#' Q4 <- as.factor(sample(1:6, 500, replace = TRUE, prob = c(0.2,0.1,0.1,0.4,0.1,0.1)))
-#' Q5 <- as.factor(sample(1:6, 500, replace = TRUE, prob = c(0.1,0.4,0.1,0.3,0.05,0.15)))
-#' 
-#' likert_6 <- data.frame(Q1, Q2, Q3, Q4, Q5)
-#'
-#' # create labels
-#' levels_6 <- c("Very strongly agree", "Strongly agree", "Agree",
-#'               "Disagree", "Strongly disagree", "Very strongly disagree")
-#' 
 #' # create item labels
 #' items <- c("Q1", "Q2", "Q3", "Q4", "Q5")
 #' 
-#' # plot dichotomous likert scale, ordered by "negative" values
-#' sjp.likert(likert_2, geom.colors = c("green", "red"), legend.labels = levels_2, 
-#'            axis.labels = items, sort.frq = "neg.desc")
-#' 
-#' # plot 4-category-likert-scale, no order
+#' # plot 4-category-likert-scale, no sorting
 #' sjp.likert(likert_4, cat.neutral = 5, legend.labels = levels_4, 
 #'            axis.labels = items, grid.range = 1.2, expand.grid = FALSE,
 #'            values = "sum.outside", show.prc.sign = TRUE)
 #' 
-#' # plot 6-category-likert-scale, ordered by positive values,
-#' # in brown color scale
-#' sjp.likert(likert_6,  legend.labels = levels_6, axis.labels = items, 
-#'            sort.frq = "pos.asc", digits = 0, show.prc.sign = TRUE,
-#'            values = "sum.inside")
+#' # Data from the EUROFAMCARE sample dataset
+#' library(dplyr)
+#' library(sjmisc)
+#' data(efc)
+#' # find all variables from COPE-Index, which all have a "cop" in their
+#' # variable name, and then plot that subset as likert-plot
+#' efc[, find_var(efc, "cop")] %>% sjp.likert()
 #' 
 #' @import ggplot2
 #' @importFrom stats na.omit xtabs
@@ -277,6 +249,27 @@ sjp.likert <- function(items,
   mydat.dk <- data.frame()
   freq.df <- data.frame()
   # --------------------------------------------------------
+  # If we have neutral category in between and not as last
+  # category, recode neutral category to last category
+  # --------------------------------------------------------
+  if (!is.null(cat.neutral) && cat.neutral <= catcount) {
+    # first, each other category has to be moved down one position
+    # therefore, we create a pattern with values from neutral
+    # category to category count
+    downvote <- seq(cat.neutral, catcount + 1, by = 1)
+    # now we "shift" this value pattern and make a
+    # string out of it
+    recode.pattern <- paste0(
+      paste0(sprintf("%i=%i", c(downvote[-1], downvote[1]), downvote),
+             collapse = ";"), ";else=copy"
+      )
+    # finally, recode data
+    items <- sjmisc::rec(items, recodes = recode.pattern)
+    # re-order legend labels as well
+    ll.order <- c(seq_len(catcount + adding)[-cat.neutral], cat.neutral)
+    legend.labels <- legend.labels[ll.order]
+  }
+  # --------------------------------------------------------
   # loop through all likert-items
   # --------------------------------------------------------
   for (i in seq_len(ncol(items))) {
@@ -290,24 +283,6 @@ sjp.likert <- function(items,
       items[[i]] <- sjmisc::to_value(items[[i]], keep.labels = F)
     }
     # --------------------------------------------------------
-    # If we have neutral category in between and not as last
-    # category, recode neutral category to last category
-    # --------------------------------------------------------
-    if (!is.null(cat.neutral) && cat.neutral <= catcount) {
-      # first, each other category has to be moved down one position
-      # therefore, we create a pattern with values from neutral
-      # category to category count
-      downvote <- seq(cat.neutral, catcount + 1, by = 1)
-      # now we "shift" this value pattern and make a
-      # string out of it
-      recode.pattern <- paste0(paste0(sprintf("%i=%i",
-                                              c(downvote[-1], downvote[1]),
-                                              downvote),
-                                      collapse = ";"), ";else=copy")
-      # finally, recode data
-      items[[i]] <- sjmisc::rec(items[[i]], recodes = recode.pattern)
-    }
-    # --------------------------------------------------------
     # If we don't plot neutral category, but item still contains
     # that category, replace it with NA
     # --------------------------------------------------------
@@ -395,7 +370,7 @@ sjp.likert <- function(items,
   # data rows in this data frame and now need to "split"
   # positive and negative values
   # --------------------------------------------------------
-  for (i in 1:ncol(freq.df)) {
+  for (i in seq_len(ncol(freq.df))) {
     # sort
     fr <- freq.df[, sort.freq[i]]
     # --------------------------------------------------------
@@ -497,22 +472,21 @@ sjp.likert <- function(items,
   # --------------------------------------------------------
   # Set up grid breaks
   # --------------------------------------------------------
-  gridbreaks <- round(c(seq(-grid.range, grid.range, by = grid.breaks)), 2)
-  gridlabs <- ifelse(abs(gridbreaks) > 1, "", paste0(c(abs(round(100 * gridbreaks))), "%"))
+  gridbreaks <- round(seq(-grid.range, grid.range, by = grid.breaks), 2)
+  gridlabs <- ifelse(abs(gridbreaks) > 1, "", paste0(abs(round(100 * gridbreaks)), "%"))
   # --------------------------------------------------------
   # start plot here
   # --------------------------------------------------------
   gp <- ggplot() +
     # positive value bars
-    geom_bar(data = mydat.pos, 
+    geom_col(data = mydat.pos, 
              aes_string(x = "x", y = "frq", fill = "grp"), 
-             width = geom.size, 
-             stat = "identity") +
+             width = geom.size) +
     # negative value bars
-    geom_bar(data = mydat.neg, 
+    geom_col(data = mydat.neg, 
              aes_string(x = "x", y = "frq", fill = "grp"), 
-             width = geom.size, 
-             stat = "identity")
+             width = geom.size,
+             position = position_stack(reverse = T))
   # --------------------------------------------------------
   # print bar for neutral category. this is a "fake" bar created
   # with geom_rect. to make this work, we need to set the x-axis
